@@ -28,8 +28,9 @@ from .parse_nodes import (
     Subscript,
 )
 
-# technically args can be anything...but most of the time it'll be labels
-Arg = t.Union[str, list]
+# argument to a function. technically can be anything...but most of the time
+# it'll be labels
+Arg = t.Any
 
 Args = t.Dict[str, Arg]
 
@@ -53,6 +54,11 @@ class SeriesResult(EvalResult):
     val: pd.Series
 
 
+@dataclasses.dataclass
+class ScalarResult(EvalResult):
+    val: t.Any
+
+
 @dataclasses.dataclass
 class GroupbyResult(EvalResult):
     val: util.DataFrameGroupBy
@@ -174,6 +180,15 @@ def run_code(root: ParseResult, ipython_shell=None) -> t.List[EvalResult]:
     # https://github.com/SamLau95/pandas_tutor/issues/42
     for result in eval_results:
         result.step.code = last_expr.code
+
+    # now, let's exec the last statement in case it defines a variable that the
+    # user will use later in their notebook
+    try:
+        exec(last_expr.code, user_globals)
+    except Exception:
+        # we handle errors in the last expr above
+        pass
+
     return eval_results
 
 
@@ -201,6 +216,8 @@ def make_result(
         return DFResult(step, fragment, args, val)
     elif isinstance(val, pd.Series):
         return SeriesResult(step, fragment, args, val)
+    elif util.is_scalar(val):
+        return ScalarResult(step, fragment, args, val)
     elif util.is_plottable(val):
         return ImageResult(step, fragment, args, val)
     else:
